#

##

##

    	unites

    	description

    		These are ingredients that are part
    		of the ingredient.

    	structure

    		{
    			"unites": [
    				{
    					"info": {
    						"includes": [],
    						"names": [
    							"dietary fiber",
    							"fiber, total dietary"
    						],
    						"region": 6
    					},
    					"measures": {
    						"mass + mass equivalents": {
    							"per recipe": {
    								"grams": {
    									"fraction string": "305884486691004077/45035996273704960",
    									"scinote string": "6.7920e+0"
    								}
    							}
    						}
    					},
    					"natures": [
    						{
    							"amount": "1",
    							"source": {
    								"name": "PLANT-BASED CHOPPED CHICK'N",
    								"FDC ID": "2510083",
    								"UPC": "850002856132",
    								"DSLD ID": ""
    							},
    							"ingredient": {
    								"name": "Fiber, total dietary"
    							},
    							"measures": {
    								"mass + mass equivalents": {
    									"per package": {
    										"listed": [
    											"6.792",
    											"g"
    										],
    										"grams": {
    											"scinote string": "6.7920e+0",
    											"decimal string": "6.792",
    											"fraction string": "305884486691004077/45035996273704960"
    										}
    									}
    								}
    							}
    						}
    					],
    					"unites": [],
    					"goals": {
    						"days of ingredient": {
    							"mass + mass equivalents": {
    								"per recipe": {
    									"fraction string": "305884486691004077/1261007895663738880",
    									"decimal string": "0.243"
    								}
    							}
    						}
    					}
    				}
    			]
    		}